@@ -212,7 +212,16 @@ def enable_python_hooks(ij):
 def prepare_deepslice_temp_folder(self):
     print('pdtf0')
     if not hasattr(self, '_run_deep_slice'):
-        from abba_private.DeepSliceProcessor import DeepSliceProcessor
+        try:
+            from abba_python.abba_private.DeepSliceProcessor import \
+                DeepSliceProcessor  # delayed import because the jvm should be set first
+        except:
+            try:
+                from .abba_private.DeepSliceProcessor import \
+                    DeepSliceProcessor  # delayed import because the jvm should be set first
+            except:
+                print("Could not import DeepSliceProcessor because the dev do not understand python modules and submodules.")
+
         self._run_deep_slice = DeepSliceProcessor()
 
     print('pdtf1')
